@@ -32,13 +32,14 @@ import six.moves.urllib.parse as urlparse
 
 from cliff import app
 from cliff import commandmanager
+from neutronclient._i18n import _
 from neutronclient.common import clientmanager
 from neutronclient.common import exceptions as exc
 from neutronclient.common import utils
-from neutronclient.i18n import _
 from neutronclient.version import __version__
 
 from gbpclient.gbp.v2_0 import groupbasedpolicy as gbp
+from gbpclient.gbp.v2_0 import purge
 from gbpclient.gbp.v2_0 import servicechain
 
 VERSION = '2.0'
@@ -102,6 +103,11 @@ COMMAND_V2 = {
     'group-update': gbp.UpdatePolicyTargetGroup,
     'group-list': gbp.ListPolicyTargetGroup,
     'group-show': gbp.ShowPolicyTargetGroup,
+    'application-policy-group-create': gbp.CreateApplicationPolicyGroup,
+    'application-policy-group-delete': gbp.DeleteApplicationPolicyGroup,
+    'application-policy-group-update': gbp.UpdateApplicationPolicyGroup,
+    'application-policy-group-list': gbp.ListApplicationPolicyGroup,
+    'application-policy-group-show': gbp.ShowApplicationPolicyGroup,
     'l2policy-create': gbp.CreateL2Policy,
     'l2policy-delete': gbp.DeleteL2Policy,
     'l2policy-update': gbp.UpdateL2Policy,
@@ -152,6 +158,7 @@ COMMAND_V2 = {
     'policy-rule-set-update': gbp.UpdatePolicyRuleSet,
     'policy-rule-set-list': gbp.ListPolicyRuleSet,
     'policy-rule-set-show': gbp.ShowPolicyRuleSet,
+    'purge': purge.Purge,
     'service-profile-list': servicechain.ListServiceProfile,
     'service-profile-show': servicechain.ShowServiceProfile,
     'service-profile-create': servicechain.CreateServiceProfile,
@@ -192,6 +199,11 @@ COMMAND_V2 = {
     'ptg-update': gbp.UpdatePolicyTargetGroup,
     'ptg-list': gbp.ListPolicyTargetGroup,
     'ptg-show': gbp.ShowPolicyTargetGroup,
+    'apg-create': gbp.CreateApplicationPolicyGroup,
+    'apg-delete': gbp.DeleteApplicationPolicyGroup,
+    'apg-update': gbp.UpdateApplicationPolicyGroup,
+    'apg-list': gbp.ListApplicationPolicyGroup,
+    'apg-show': gbp.ShowApplicationPolicyGroup,
     'l2p-create': gbp.CreateL2Policy,
     'l2p-delete': gbp.DeleteL2Policy,
     'l2p-update': gbp.UpdateL2Policy,
